<?php
/**
 * @package         NoNumber Extension Manager
 * @version         4.3.1
 *
 * @author          Peter van Westen <peter@nonumber.nl>
 * @link            http://www.nonumber.nl
 * @copyright       Copyright © 2014 NoNumber All Rights Reserved
 * @license         http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 */

defined('_JEXEC') or die;

jimport('joomla.application.component.view');

/**
 * View class for default list view
 */
class ARKManagerViewDefault extends JViewLegacy
{
	protected $items;

	/**
	 * Display the view
	 */
	public function display($tpl = null)
	{
		$this->items = $this->get('Items');

		if (JFactory::getApplication()->input->get('task') == 'update') {
			$tpl = 'update';
		} else {
			$this->addToolbar();
		}
		// Include the component HTML helpers.
		JHtml::addIncludePath(JPATH_COMPONENT . '/helpers/html');
		parent::display($tpl);
	}

	/**
	 * Function that gets the config settings
	 */
	protected function getConfig()
	{
		if (!isset($this->config)) {
			require_once JPATH_PLUGINS . '/system/arkframework/helpers/parameters.php';
			$parameters = ARKMANParameters::getInstance();
			$this->config = $parameters->getComponentParams('arkmanager');
		}
		return $this->config;
	}

	/**
	 * Add the page title and toolbar
	 */
	protected function addToolbar()
	{
		$canDo = $this->getActions();

		JFactory::getDocument()->setTitle(JText::_('ARK_EXTENSION_MANAGER'));

		JToolbarHelper::title(JText::_('ARK_EXTENSION_MANAGER'), 'arkmanager');

		ARKManagerToolbarHelper::addButtons();

		if ($canDo->get('core.admin')) {
			JToolbarHelper::preferences('com_arkmanager', '400');
		}
	}

	/**
	 * Gets a list of the actions that can be performed.
	 */
	public static function getActions()
	{
		$user = JFactory::getUser();
		$result = new JObject;
		$assetName = 'com_arkmanager';

		$actions = array(
			'core.admin', 'core.manage'
		);

		foreach ($actions as $action) {
			$result->set($action, $user->authorise($action, $assetName));
		}

		return $result;
	}
}

class ARKManagerToolbarHelper extends JToolbarHelper
{
	public static function addButtons()
	{
		$bar = JToolbar::getInstance('toolbar');

		$html = '
			</div>

          	<div class="btn-wrapper hidden-phone">
				<button class="refresh btn btn-small" onclick="window.location=\'index.php?option=com_arkmanager&view=instructions\'" rel="tooltip" title="' . JText::_('AEM_BACK_DESC') . '">
					<span class="icon-user"></span>	'.JText::_('AEM_BACK').'
				</button>
			</div>
			
          	<div class="btn-wrapper ark-hide-desktop">
				<button class="refresh btn btn-small" onclick="window.location=\'index.php?option=com_arkmanager&view=instructions\'">
					<span class="icon-user"></span>	'.JText::_('AEM_BACK').'
				</button>
			</div>
			<div class="btn-wrapper hidden-phone">
				<button class="refresh btn btn-small" onclick="arkem_function(\'refresh\');" rel="tooltip" title="' . JText::_('AEM_REFRESH_DESC') . '">
					<span class="icon-refresh"></span>&nbsp;
				</button>
			</div>
			<div class="btn-wrapper ark-hide-desktop">
				<button class="refresh btn btn-small" onclick="arkem_function(\'refresh\');">
					<span class="icon-refresh"></span>&nbsp;
				</button>
			</div>
			
			
			<div class="btn-wrapper hidden-phone installselected_disabled" id="toolbar-installselected_disabled">
				<button class="btn btn-small disabled">
					<span class="icon-box-add"></span> ' . JText::_('AEM_INSTALL_SELECTED') . '
				</button>
			</div>
			<div class="btn-wrapper hidden-phone installselected" id="toolbar-installselected">
				<button class="btn btn-small btn-info hidden-phone" onclick="arkem_function(\'installselected\');" rel="tooltip" title="' . JText::_('AEM_INSTALL_SELECTED_DESC') . '">
					<span class="icon-box-add"></span> ' . JText::_('AEM_INSTALL_SELECTED') . '
				</button>
			</div>

			<div class="btn-wrapper updateall_disabled" id="toolbar-updateall_disabled">
				<button class="btn btn-small disabled">
					<span class="icon-upload"></span> ' . JText::_('AEM_UPDATE_ALL') . '
				</button>
			</div>
			
			<div class="btn-wrapper updateall hidden-phone" id="toolbar-updateall">
				<button class="btn btn-small btn-warning" onclick="arkem_function(\'updateall\');" rel="tooltip" title="' . JText::_('AEM_UPDATE_ALL_DESC') . '">
					<span class="icon-upload"></span> ' . JText::_('AEM_UPDATE_ALL') . '
				</button>
			</div>
			
			<div class="btn-wrapper updateall ark-hide-desktop" id="toolbar-updateall">
				<button class="btn btn-small btn-warning" onclick="arkem_function(\'updateall\');">
					<span class="icon-upload"></span> ' . JText::_('AEM_UPDATE_ALL') . '
				</button>
		';
		$bar->appendButton('Custom', $html);
	}
}